from setuptools import setup

setup(
    name = "probabulity_distributions",
    versions = '0.1',
    description= 'Gaussian and Binomial Distributions Distributions',
    packages = ['probability_distributions'],
    author = 'Vinlaw ZP Mudehwe',
    author_email = 'vmudehwe3661@gmail.com',
    zip_safe = False)